summary refs log tree commit diff
diff options
context:
space:
mode:
authorokan <okan>2011-03-23 07:27:32 +0000
committerokan <okan>2011-03-23 07:27:32 +0000
commit349b3295b8791fd08fbf1307576fe8ecd2c3f374 (patch)
treeed23bde1fb9afcdc1747043d9b5d5f930e30ef0e
parent5972c7a507d37556b378b9490d56de296f9396e2 (diff)
downloadcwm-349b3295b8791fd08fbf1307576fe8ecd2c3f374.tar.gz
cwm-349b3295b8791fd08fbf1307576fe8ecd2c3f374.tar.xz
cwm-349b3295b8791fd08fbf1307576fe8ecd2c3f374.zip
revert the XSync timing change for client move only; first noticed by
brynet.

sure oga@
-rw-r--r--mousefunc.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/mousefunc.c b/mousefunc.c
index 3707f65..074f090 100644
--- a/mousefunc.c
+++ b/mousefunc.c
@@ -159,8 +159,8 @@ mousefunc_window_move(struct client_ctx *cc, void *arg)
 			cc->geom.x = ev.xmotion.x_root - px - cc->bwidth;
 			cc->geom.y = ev.xmotion.y_root - py - cc->bwidth;
 
-			/* don't sync more than 10 times / second */
-			if ((ev.xmotion.time - time) > (1000 / 10)) {
+			/* don't sync more than 60 times / second */
+			if ((ev.xmotion.time - time) > (1000 / 60)) {
 				time = ev.xmotion.time;
 				XSync(X_Dpy, False);
 				client_move(cc);